# Utilities

The soxspipe utilities can be viewed as the tool-kit with which the [soxspipe recipes](../recipes/index.md) are built. Many of these utilities are used across multiple recipes and they can either be stand-alone objects or methods of the recipe itself.


```eval_rst
.. toctree::
   :maxdepth: 4

   clip_and_stack
   create_dispersion_map
   create_noise_map
   detect_continuum
   detect_order_edges
   detector_lookup
   filenamer
   keyword_lookup
   prepare_frames
   set_of_files
   subtract_background
   detrend
```

